@@ -72,7 +72,7 @@ class DeviantartExtractor(Extractor):
     def items(self):
         self.api = DeviantartOAuthAPI(self)
 
-        if self.user:
+        if self.user and self.config("group", True):
             profile = self.api.user_profile(self.user)
             self.group = not profile
             if self.group:
@@ -417,8 +417,8 @@ class DeviantartGalleryExtractor(DeviantartExtractor):
     pattern = BASE_PATTERN + r"/gallery(?:/all|/?\?catpath=)?/?$"
     test = (
         ("https://www.deviantart.com/shimoda7/gallery/", {
-            "pattern": r"https://(api-da\.wixmp\.com/_api/download/file"
-                       r"|images-wixmp-[^.]+.wixmp.com/f/.+/.+.jpg\?token=.+)",
+            "pattern": r"https://(images-)?wixmp-[^.]+\.wixmp\.com"
+                       r"/f/.+/.+\.(jpg|png)\?token=.+",
             "count": ">= 30",
             "keyword": {
                 "allows_comments": bool,
@@ -563,7 +563,8 @@ class DeviantartStashExtractor(DeviantartExtractor):
     pattern = r"(?:https?://)?sta\.sh/([a-z0-9]+)"
     test = (
         ("https://sta.sh/022c83odnaxc", {
-            "pattern": r"https://api-da\.wixmp\.com/_api/download/file",
+            "pattern": r"https://wixmp-[^.]+\.wixmp\.com"
+                       r"/f/.+/.+\.png\?token=.+",
             "content": "057eb2f2861f6c8a96876b13cca1a4b7a408c11f",
             "count": 1,
         }),
@@ -574,7 +575,8 @@ class DeviantartStashExtractor(DeviantartExtractor):
         }),
         # downloadable, but no "content" field (#307)
         ("https://sta.sh/024t4coz16mi", {
-            "pattern": r"https://api-da\.wixmp\.com/_api/download/file",
+            "pattern": r"https://wixmp-[^.]+\.wixmp\.com"
+                       r"/f/.+/.+\.rar\?token=.+",
             "count": 1,
         }),
         # mixed folders and images (#659)
@@ -601,22 +603,22 @@ class DeviantartStashExtractor(DeviantartExtractor):
         page = self._limited_request(url).text
 
         if stash_id[0] == "0":
-            uuid = text.extract(page, '//deviation/', '"')[0]
+            uuid = text.extr(page, '//deviation/', '"')
             if uuid:
                 deviation = self.api.deviation(uuid)
-                deviation["index"] = text.parse_int(text.extract(
-                    page, 'gmi-deviationid="', '"')[0])
+                deviation["index"] = text.parse_int(text.extr(
+                    page, 'gmi-deviationid="', '"'))
                 yield deviation
                 return
 
         for item in text.extract_iter(
                 page, 'class="stash-thumb-container', '</div>'):
-            url = text.extract(item, '<a href="', '"')[0]
+            url = text.extr(item, '<a href="', '"')
 
             if url:
                 stash_id = url.rpartition("/")[2]
             else:
-                stash_id = text.extract(item, 'gmi-stashid="', '"')[0]
+                stash_id = text.extr(item, 'gmi-stashid="', '"')
                 stash_id = "2" + util.bencode(text.parse_int(
                     stash_id), "0123456789abcdefghijklmnopqrstuvwxyz")
 
@@ -669,12 +671,12 @@ class DeviantartCollectionExtractor(DeviantartExtractor):
     test = (
         (("https://www.deviantart.com/pencilshadings/favourites"
           "/70595441/3D-Favorites"), {
-            "count": ">= 20",
+            "count": ">= 15",
             "options": (("original", False),),
         }),
         (("https://www.deviantart.com/pencilshadings/favourites"
           "/F050486B-CB62-3C66-87FB-1105A7F6379F/3D Favorites"), {
-            "count": ">= 20",
+            "count": ">= 15",
             "options": (("original", False),),
         }),
         ("https://pencilshadings.deviantart.com"
@@ -863,8 +865,9 @@ class DeviantartDeviationExtractor(DeviantartExtractor):
         }),
         (("https://www.deviantart.com/myria-moon/art/Aime-Moi-261986576"), {
             "options": (("comments", True),),
-            "pattern": r"https://api-da\.wixmp\.com/_api/download/file",
             "keyword": {"comments": list},
+            "pattern": r"https://wixmp-[^.]+\.wixmp\.com"
+                       r"/f/.+/.+\.jpg\?token=.+",
         }),
         # wixmp URL rewrite
         (("https://www.deviantart.com/citizenfresh/art/Hverarond-789295466"), {
@@ -873,13 +876,14 @@ class DeviantartDeviationExtractor(DeviantartExtractor):
         }),
         # GIF (#242)
         (("https://www.deviantart.com/skatergators/art/COM-Moni-781571783"), {
-            "pattern": (r"https://images-wixmp-\w+\.wixmp\.com"
-                        r"/f/[^/]+/[^.]+\.gif\?token="),
+            "pattern": r"https://wixmp-\w+\.wixmp\.com/f/03fd2413-efe9-4e5c-"
+                       r"8734-2b72605b3fbb/dcxbsnb-1bbf0b38-42af-4070-8878-"
+                       r"f30961955bec\.gif\?token=ey...",
         }),
         # Flash animation with GIF preview (#1731)
         ("https://www.deviantart.com/yuumei/art/Flash-Comic-214724929", {
-            "pattern": r"https://api-da\.wixmp\.com/_api/download"
-                       r"/file\?downloadToken=.+",
+            "pattern": r"https://wixmp-[^.]+\.wixmp\.com"
+                       r"/f/.+/.+\.swf\?token=.+",
             "keyword": {
                 "filename": "flash_comic_tutorial_by_yuumei-d3juatd",
                 "extension": "swf",
@@ -932,12 +936,13 @@ class DeviantartDeviationExtractor(DeviantartExtractor):
         self.deviation_id = match.group(4)
 
     def deviations(self):
-        deviation = DeviantartEclipseAPI(self).deviation_extended_fetch(
-            self.deviation_id, self.user, self.type)
-        if "error" in deviation:
+        url = "{}/{}/{}/{}".format(
+            self.root, self.user, self.type, self.deviation_id)
+        uuid = text.extract(self._limited_request(url).text,
+                            '"deviationUuid\\":\\"', '\\')[0]
+        if not uuid:
             raise exception.NotFoundError("deviation")
-        return (self.api.deviation(
-            deviation["deviation"]["extended"]["deviationUuid"]),)
+        return (self.api.deviation(uuid),)
 
 
 class DeviantartScrapsExtractor(DeviantartExtractor):
@@ -955,9 +960,15 @@ class DeviantartScrapsExtractor(DeviantartExtractor):
     )
     cookiedomain = ".deviantart.com"
     cookienames = ("auth", "auth_secure", "userinfo")
+    _warning = True
 
     def deviations(self):
         eclipse_api = DeviantartEclipseAPI(self)
+        if self._warning:
+            DeviantartScrapsExtractor._warning = False
+            if not self._check_cookies(self.cookienames):
+                self.log.warning(
+                    "No session cookies set: Unable to fetch mature scraps.")
 
         for obj in eclipse_api.gallery_scraps(self.user, self.offset):
             deviation = obj["deviation"]
@@ -1015,6 +1026,7 @@ class DeviantartOAuthAPI():
 
         self.folders = extractor.config("folders", False)
         self.metadata = extractor.extra or extractor.config("metadata", False)
+        self.strategy = extractor.config("pagination")
 
         self.client_id = extractor.config("client-id")
         if self.client_id:
@@ -1123,11 +1135,18 @@ class DeviantartOAuthAPI():
             self._folders((deviation,))
         return deviation
 
-    def deviation_content(self, deviation_id, public=False):
+    def deviation_content(self, deviation_id, public=True):
         """Get extended content of a single Deviation"""
         endpoint = "/deviation/content"
         params = {"deviationid": deviation_id}
-        return self._call(endpoint, params=params, public=public)
+        content = self._call(endpoint, params=params, public=public)
+        if public and content["html"].startswith(
+                '        <span class=\"username-with-symbol'):
+            if self.refresh_token_key:
+                content = self._call(endpoint, params=params, public=False)
+            else:
+                self.log.warning("Private Journal")
+        return content
 
     def deviation_download(self, deviation_id, public=True):
         """Get the original file download (if allowed)"""
@@ -1306,14 +1325,20 @@ class DeviantartOAuthAPI():
                     self._folders(results)
             yield from results
 
-            if not data["has_more"]:
+            if not data["has_more"] and (
+                    self.strategy != "manual" or not results or not extend):
                 return
+
             if "next_cursor" in data:
                 params["offset"] = None
                 params["cursor"] = data["next_cursor"]
-            else:
+            elif data["next_offset"] is not None:
                 params["offset"] = data["next_offset"]
                 params["cursor"] = None
+            else:
+                if params.get("offset") is None:
+                    return
+                params["offset"] = int(params["offset"]) + len(results)
 
     def _pagination_list(self, endpoint, params, key="results"):
         result = []
@@ -1380,6 +1405,8 @@ class DeviantartEclipseAPI():
     def __init__(self, extractor):
         self.extractor = extractor
         self.log = extractor.log
+        self.request = self.extractor._limited_request
+        self.csrf_token = None
 
     def deviation_extended_fetch(self, deviation_id, user=None, kind=None):
         endpoint = "/da-browse/shared_api/deviation/extended_fetch"
@@ -1411,11 +1438,12 @@ class DeviantartEclipseAPI():
         }
         return self._pagination(endpoint, params)
 
-    def _call(self, endpoint, params=None):
+    def _call(self, endpoint, params):
         url = "https://www.deviantart.com/_napi" + endpoint
         headers = {"Referer": "https://www.deviantart.com/"}
+        params["csrf_token"] = self.csrf_token or self._fetch_csrf_token()
 
-        response = self.extractor._limited_request(
+        response = self.request(
             url, params=params, headers=headers, fatal=None)
 
         if response.status_code == 404:
@@ -1446,12 +1474,20 @@ class DeviantartEclipseAPI():
 
     def _module_id_watching(self, user):
         url = "{}/{}/about".format(self.extractor.root, user)
-        page = self.extractor._limited_request(url).text
+        page = self.request(url).text
         pos = page.find('\\"type\\":\\"watching\\"')
         if pos < 0:
             raise exception.NotFoundError("module")
+        self._fetch_csrf_token(page)
         return text.rextract(page, '\\"id\\":', ',', pos)[0].strip('" ')
 
+    def _fetch_csrf_token(self, page=None):
+        if page is None:
+            page = self.request(self.extractor.root + "/").text
+        self.csrf_token = token = text.extr(
+            page, "window.__CSRF_TOKEN__ = '", "'")
+        return token
+
 
 @cache(maxage=100*365*24*3600, keyarg=0)
 def _refresh_token_cache(token):
