@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2019-2021 Mike Fährmann
+# Copyright 2019-2022 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -20,34 +20,33 @@ class PatreonExtractor(Extractor):
     """Base class for patreon extractors"""
     category = "patreon"
     root = "https://www.patreon.com"
+    cookiedomain = ".patreon.com"
     directory_fmt = ("{category}", "{creator[full_name]}")
     filename_fmt = "{id}_{title}_{num:>02}.{extension}"
     archive_fmt = "{id}_{num}"
     browser = "firefox"
+    tls12 = False
     _warning = True
 
     def items(self):
 
         if self._warning:
-            if "session_id" not in self.session.cookies:
+            if not self._check_cookies(("session_id",)):
                 self.log.warning("no 'session_id' cookie set")
             PatreonExtractor._warning = False
+        generators = self._build_file_generators(self.config("files"))
 
         for post in self.posts():
 
             if not post.get("current_user_can_view", True):
                 self.log.warning("Not allowed to view post %s", post["id"])
                 continue
+            yield Message.Directory, post
+
             post["num"] = 0
             hashes = set()
-
-            yield Message.Directory, post
-            for kind, url, name in itertools.chain(
-                self._images(post),
-                self._attachments(post),
-                self._postfile(post),
-                self._content(post),
-            ):
+            for kind, url, name in itertools.chain.from_iterable(
+                    g(post) for g in generators):
                 fhash = self._filehash(url)
                 if fhash not in hashes or not fhash:
                     hashes.add(fhash)
@@ -72,6 +71,15 @@ class PatreonExtractor(Extractor):
                 name = image.get("file_name") or self._filename(url) or url
                 yield "image", url, name
 
+    def _image_large(self, post):
+        image = post.get("image")
+        if image:
+            url = image.get("large_url")
+            if url:
+                name = image.get("file_name") or self._filename(url) or url
+                return (("image_large", url, name),)
+        return ()
+
     def _attachments(self, post):
         for attachment in post["attachments"]:
             url = self.request(
@@ -82,15 +90,14 @@ class PatreonExtractor(Extractor):
             if url:
                 yield "attachment", url, attachment["name"]
 
-    @staticmethod
-    def _content(post):
+    def _content(self, post):
         content = post.get("content")
         if content:
             for img in text.extract_iter(
                     content, '<img data-media-id="', '>'):
-                url = text.extract(img, 'src="', '"')[0]
+                url = text.extr(img, 'src="', '"')
                 if url:
-                    yield "content", url, url
+                    yield "content", url, self._filename(url) or url
 
     def posts(self):
         """Return all relevant post objects"""
@@ -174,7 +181,7 @@ class PatreonExtractor(Extractor):
         """Fetch filename from an URL's Content-Disposition header"""
         response = self.request(url, method="HEAD", fatal=False)
         cd = response.headers.get("Content-Disposition")
-        return text.extract(cd, 'filename="', '"')[0]
+        return text.extr(cd, 'filename="', '"')
 
     @staticmethod
     def _filehash(url):
@@ -212,6 +219,21 @@ class PatreonExtractor(Extractor):
             "&json-api-version=1.0"
         )
 
+    def _build_file_generators(self, filetypes):
+        if filetypes is None:
+            return (self._images, self._image_large,
+                    self._attachments, self._postfile, self._content)
+        genmap = {
+            "images"     : self._images,
+            "image_large": self._image_large,
+            "attachments": self._attachments,
+            "postfile"   : self._postfile,
+            "content"    : self._content,
+        }
+        if isinstance(filetypes, str):
+            filetypes = filetypes.split(",")
+        return [genmap[ft] for ft in filetypes]
+
 
 class PatreonCreatorExtractor(PatreonExtractor):
     """Extractor for a creator's works"""
@@ -262,7 +284,7 @@ class PatreonCreatorExtractor(PatreonExtractor):
             url = "{}/{}/posts".format(self.root, self.creator)
 
         page = self.request(url, notfound="creator").text
-        campaign_id = text.extract(page, "/campaign/", "/")[0]
+        campaign_id = text.extr(page, "/campaign/", "/")
         if not campaign_id:
             raise exception.NotFoundError("creator")
 
@@ -305,8 +327,9 @@ class PatreonPostExtractor(PatreonExtractor):
             "count": 4,
         }),
         # postfile + content
-        ("https://www.patreon.com/posts/19987002", {
-            "count": 4,
+        ("https://www.patreon.com/posts/56127163", {
+            "count": 3,
+            "keyword": {"filename": r"re:^(?!1).+$"},
         }),
         # tags (#1539)
         ("https://www.patreon.com/posts/free-post-12497641", {
