@@ -124,6 +124,11 @@ def build_parser():
         dest="source-address", metavar="IP", action=ConfigAction,
         help="Client-side IP address to bind to",
     )
+    general.add_argument(
+        "--user-agent",
+        dest="user-agent", metavar="UA", action=ConfigAction,
+        help="User-Agent request header",
+    )
     general.add_argument(
         "--clear-cache",
         dest="clear_cache", metavar="MODULE",
@@ -262,6 +267,11 @@ def build_parser():
         dest="filesize-max", metavar="SIZE", action=ConfigAction,
         help="Do not download files larger than SIZE (e.g. 500k or 2.5M)",
     )
+    downloader.add_argument(
+        "--chunk-size",
+        dest="chunk-size", metavar="SIZE", action=ConfigAction,
+        help="Size of in-memory data chunks (default: 32k)",
+    )
     downloader.add_argument(
         "--no-part",
         dest="part", nargs=0, action=ConfigConstAction, const=False,
