@@ -15,6 +15,7 @@ import io
 import random
 import string
 import datetime
+import itertools
 import http.cookiejar
 
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
@@ -168,11 +169,12 @@ class TestISO639_1(unittest.TestCase):
 
 class TestCookiesTxt(unittest.TestCase):
 
-    def test_load_cookiestxt(self):
+    def test_cookiestxt_load(self):
 
         def _assert(content, expected):
-            cookies = util.load_cookiestxt(io.StringIO(content, None))
-            for c, e in zip(cookies, expected):
+            jar = http.cookiejar.CookieJar()
+            util.cookiestxt_load(io.StringIO(content, None), jar)
+            for c, e in zip(jar, expected):
                 self.assertEqual(c.__dict__, e.__dict__)
 
         _assert("", [])
@@ -218,13 +220,14 @@ class TestCookiesTxt(unittest.TestCase):
         )
 
         with self.assertRaises(ValueError):
-            util.load_cookiestxt("example.org\tTRUE\t/\tTRUE\t0\tname")
+            util.cookiestxt_load("example.org\tTRUE\t/\tTRUE\t0\tname",
+                                 http.cookiejar.CookieJar())
 
-    def test_save_cookiestxt(self):
+    def test_cookiestxt_store(self):
 
         def _assert(cookies, expected):
             fp = io.StringIO(newline=None)
-            util.save_cookiestxt(fp, cookies)
+            util.cookiestxt_store(fp, cookies)
             self.assertMultiLineEqual(fp.getvalue(), expected)
 
         _assert([], "# Netscape HTTP Cookie File\n\n")
@@ -385,8 +388,6 @@ class TestOther(unittest.TestCase):
             expr()
 
     def test_build_duration_func(self, f=util.build_duration_func):
-        for v in (0, 0.0, "", None, (), []):
-            self.assertIsNone(f(v))
 
         def test_single(df, v):
             for _ in range(10):
@@ -398,6 +399,12 @@ class TestOther(unittest.TestCase):
                 self.assertGreaterEqual(v, lower)
                 self.assertLessEqual(v, upper)
 
+        for v in (0, 0.0, "", None, (), []):
+            self.assertIsNone(f(v))
+
+        for v in (0, 0.0, "", None, (), []):
+            test_single(f(v, 1.0), 1.0)
+
         test_single(f(3), 3)
         test_single(f(3.0), 3.0)
         test_single(f("3"), 3)
@@ -535,6 +542,41 @@ class TestOther(unittest.TestCase):
         r = util.filter_dict(d)
         self.assertEqual(r, {"foo": 123})
 
+    def test_enumerate_reversed(self):
+
+        seq = [11, 22, 33]
+        result = [(3, 33), (2, 22), (1, 11)]
+
+        def gen():
+            for i in seq:
+                yield i
+
+        def gen_2():
+            yield from seq
+
+        def assertEqual(it1, it2):
+            ae = self.assertEqual
+            for i1, i2 in itertools.zip_longest(it1, it2):
+                ae(i1, i2)
+
+        assertEqual(
+            util.enumerate_reversed(seq), [(2, 33), (1, 22), (0, 11)])
+        assertEqual(
+            util.enumerate_reversed(seq, 1), result)
+        assertEqual(
+            util.enumerate_reversed(seq, 2), [(4, 33), (3, 22), (2, 11)])
+
+        assertEqual(
+            util.enumerate_reversed(gen(), 0, len(seq)),
+            [(2, 33), (1, 22), (0, 11)])
+        assertEqual(
+            util.enumerate_reversed(gen(), 1, len(seq)), result)
+        assertEqual(
+            util.enumerate_reversed(gen_2(), 1, len(seq)), result)
+        assertEqual(
+            util.enumerate_reversed(gen_2(), 2, len(seq)),
+            [(4, 33), (3, 22), (2, 11)])
+
     def test_number_to_string(self, f=util.number_to_string):
         self.assertEqual(f(1)     , "1")
         self.assertEqual(f(1.0)   , "1.0")
